@@ -120,8 +120,11 @@ const string anyks::Alphabet::toLower(const string & str) const noexcept {
 	if(!str.empty()){
 		// Получаем временную строку
 		wstring tmp = this->convert(result);
-		// Переходим по всем символам
-		for(auto & c : tmp) c = towlower(c);
+		// Выполняем приведение к нижнему регистру
+		transform(tmp.begin(), tmp.end(), tmp.begin(), [](wchar_t c){
+			// Приводим к нижнему регистру каждую букву
+			return towlower(c);
+		});
 		// Конвертируем обратно
 		result = this->convert(tmp);
 	}
@@ -140,8 +143,11 @@ const string anyks::Alphabet::toUpper(const string & str) const noexcept {
 	if(!str.empty()){
 		// Получаем временную строку
 		wstring tmp = this->convert(result);
-		// Переходим по всем символам
-		for(auto & c : tmp) c = towupper(c);
+		// Выполняем приведение к верхнему регистру
+		transform(tmp.begin(), tmp.end(), tmp.begin(), [](wchar_t c){
+			// Приводим к верхнему регистру каждую букву
+			return towupper(c);
+		});
 		// Конвертируем обратно
 		result = this->convert(tmp);
 	}
@@ -158,10 +164,22 @@ const string anyks::Alphabet::convert(const wstring & str) const noexcept {
 	string result = "";
 	// Если строка передана
 	if(!str.empty()){
+// Если используется BOOST
+#ifdef USE_BOOST_CONVERT
 		// Объявляем конвертер
-		wstring_convert <codecvt_utf8 <wchar_t>> conv;
+		using boost::locale::conv::utf_to_utf;
+		// Выполняем конвертирование в utf-8 строку
+		result = utf_to_utf <char> (str.c_str(), str.c_str() + str.size());
+// Если нужно использовать стандартную библиотеку
+#else
+		// Устанавливаем тип для конвертера UTF-8
+		using convert_type = codecvt_utf8 <wchar_t, 0x10ffff, little_endian>;
+		// Объявляем конвертер
+		wstring_convert <convert_type, wchar_t> conv;
+		// wstring_convert <codecvt_utf8 <wchar_t>> conv;
 		// Выполняем конвертирование в utf-8 строку
 		result = conv.to_bytes(str);
+#endif
 	}
 	// Выводим результат
 	return result;
@@ -289,10 +307,20 @@ const wstring anyks::Alphabet::convert(const string & str) const noexcept {
 	wstring result = L"";
 	// Если строка передана
 	if(!str.empty()){
+// Если используется BOOST
+#ifdef USE_BOOST_CONVERT
 		// Объявляем конвертер
-		wstring_convert <codecvt_utf8 <wchar_t>> conv;
+		using boost::locale::conv::utf_to_utf;
 		// Выполняем конвертирование в utf-8 строку
-		result.assign(conv.from_bytes(str));
+		result = utf_to_utf <wchar_t> (str.c_str(), str.c_str() + str.size());
+// Если нужно использовать стандартную библиотеку
+#else
+		// Объявляем конвертер
+		// wstring_convert <codecvt_utf8 <wchar_t>> conv;
+		wstring_convert <codecvt_utf8_utf16 <wchar_t, 0x10ffff, little_endian>> conv;
+		// Выполняем конвертирование в utf-8 строку
+		result = conv.from_bytes(str);
+#endif
 	}
 	// Выводим результат
 	return result;
@@ -307,7 +335,7 @@ const wstring anyks::Alphabet::toLower(const wstring & str) const noexcept {
 	wstring result = L"";
 	// Если строка передана
 	if(!str.empty()){
-		// Переходим по всем символам
+		// Переходим по всем буквам слова и формируем новую строку
 		for(auto & c : str) result.append(1, towlower(c));
 	}
 	// Выводим результат
@@ -323,7 +351,7 @@ const wstring anyks::Alphabet::toUpper(const wstring & str) const noexcept {
 	wstring result = L"";
 	// Если строка передана
 	if(!str.empty()){
-		// Переходим по всем символам
+		// Переходим по всем буквам слова и формируем новую строку
 		for(auto & c : str) result.append(1, towupper(c));
 	}
 	// Выводим результат
@@ -490,11 +518,7 @@ const u_short anyks::Alphabet::errors(const wstring & word) const noexcept {
 		// Получаем длину слова
 		const size_t length = word.length();
 		// Выполняем расчёт количества ошибок разрешённых для данного слова
-		// result = (length >= 9 ? 4 : (length > 5 ? 3 : (length > 3 ? 2 : (length > 2 ? 1 : 0))));
-		// result = (length >= 9 ? 4 : (length >= 5 ? 3 : (length > 2 ? 1 : 0)));
-		// result = (length >= 9 ? 4 : (length > 6 ? 3 : (length > 4 ? 2 : (length > 2 ? 1 : 0))));
-		result = (length >= 9 ? 4 : (length > 6 ? 3 : (length > 2 ? 2 : (length > 1 ? 1 : 0))));
-		// result = (length >= 9 ? 3 : (length > 6 ? 3 : (length > 2 ? 1 : 0)));
+		result = (length >= 9 ? 4 : (length > 6 ? 3 : (length > 4 ? 2 : (length > 1 ? 1 : 0))));
 	}
 	// Выводим результат
 	return result;
@@ -681,7 +705,7 @@ const bool anyks::Alphabet::isMath(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
 	// Если слово передано
-	if(letter > 0) result = (this->mathSymbols.count(letter) > 0);
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->mathSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -870,8 +894,12 @@ const bool anyks::Alphabet::isLatian(const wstring & str) const noexcept {
  * @return        результат проверки
  */
 const bool anyks::Alphabet::isPunct(const wchar_t letter) const noexcept {
+	// Результат работы функции
+	bool result = false;
 	// Проверяем на знак пунктуации
-	return (this->punctsSymbols.count(letter) > 0);
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->punctsSymbols.count(letter) > 0));
+	// Выводим результат
+	return result;
 }
 /**
  * isSpace Метод проверки является ли буква, пробелом
@@ -892,8 +920,8 @@ const bool anyks::Alphabet::isSpace(const wchar_t letter) const noexcept {
 const bool anyks::Alphabet::isGreek(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->greekSymbols.count(letter) > 0);
+	// Проверяем на греческий символ
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->greekSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -905,11 +933,20 @@ const bool anyks::Alphabet::isGreek(const wchar_t letter) const noexcept {
 const bool anyks::Alphabet::isRoute(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->routeSymbols.count(letter) > 0);
+	// Проверяем на наличие стрелки
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->routeSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
+/**
+ * isNumber Метод проверки является ли слово числом
+ * @param  word слово для проверки
+ * @return      результат проверки
+ */
+const bool anyks::Alphabet::isNumber(const string & word) const noexcept {
+	// Выполняем проверку
+	return this->isNumber(this->convert(word));
+}
 /**
  * isNumber Метод проверки является ли слово числом
  * @param  word слово для проверки
@@ -941,6 +978,24 @@ const bool anyks::Alphabet::isNumber(const wstring & word) const noexcept {
 	// Выводим результат
 	return result;
 }
+/**
+ * isLetter Метод проверки на разрешённую букву
+ * @param  letter буква для проверки
+ * @return        результат проверки
+ */
+const bool anyks::Alphabet::isLetter(const wchar_t letter) const noexcept {
+	// Выводим результат проверки
+	return (this->alphabet.find(letter) != wstring::npos);
+}
+/**
+ * isDecimal Метод проверки является ли слово дробным числом
+ * @param  word слово для проверки
+ * @return      результат проверки
+ */
+const bool anyks::Alphabet::isDecimal(const string & word) const noexcept {
+	// Выводим результат проверки
+	return this->isDecimal(this->convert(word));
+}
 /**
  * isDecimal Метод проверки является ли слово дробным числом
  * @param  word слово для проверки
@@ -993,7 +1048,7 @@ const bool anyks::Alphabet::isANumber(const wstring & word) const noexcept {
 			// Длина слова
 			const size_t length = word.length();
 			// Проверяем являются ли первая и последняя буква слова, числом
-			result = (this->isNumber({word.front()}) || this->isNumber({word.back()}));
+			result = (this->isNumber(wstring(1, word.front())) || this->isNumber(wstring(1, word.back())));
 			// Если оба варианта не сработали
 			if(!result && (length > 2)){
 				// Первое слово
@@ -1003,7 +1058,7 @@ const bool anyks::Alphabet::isANumber(const wstring & word) const noexcept {
 					// Получаем первое слово
 					first.assign(1, word.at(i));
 					// Проверяем является ли слово арабским числом
-					result = (i == j ? this->isNumber(first) : this->isNumber(first) || this->isNumber({word[j]}));
+					result = (i == j ? this->isNumber(first) : this->isNumber(first) || this->isNumber(wstring(1, word[j])));
 					// Если хоть один символ является числом, выходим
 					if(result) break;
 				}
@@ -1084,8 +1139,8 @@ const bool anyks::Alphabet::isAllowed(const wstring & word) const noexcept {
 const bool anyks::Alphabet::isSpecial(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->specialSymbols.count(letter) > 0);
+	// Проверяем на спец-символ
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->specialSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -1097,8 +1152,8 @@ const bool anyks::Alphabet::isSpecial(const wchar_t letter) const noexcept {
 const bool anyks::Alphabet::isCurrency(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->currencySymbols.count(letter) > 0);
+	// Проверяем на наличие символа курсовой валюты
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->currencySymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -1110,8 +1165,8 @@ const bool anyks::Alphabet::isCurrency(const wchar_t letter) const noexcept {
 const bool anyks::Alphabet::isPlayCards(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->playCardsSymbols.count(letter) > 0);
+	// Проверяем на наличие символа игральной карты
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->playCardsSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -1123,8 +1178,8 @@ const bool anyks::Alphabet::isPlayCards(const wchar_t letter) const noexcept {
 const bool anyks::Alphabet::isIsolation(const wchar_t letter) const noexcept {
 	// Результат работы функции
 	bool result = false;
-	// Если слово передано
-	if(letter > 0) result = (this->isolationSymbols.count(letter) > 0);
+	// Проверяем на наличие символа изоляции
+	if(letter > 0) result = ((this->letters.count(letter) < 1) && (this->isolationSymbols.count(letter) > 0));
 	// Выводим результат
 	return result;
 }
@@ -1220,7 +1275,7 @@ const bool anyks::Alphabet::check(const wchar_t letter) const noexcept {
 	// Результат проверки
 	if(letter > 0){
 		// Если это не число, тогда выполняем проверку
-		if(!(result = this->isNumber({letter}))){
+		if(!(result = this->isNumber(wstring(1, letter)))){
 			// Выполняем проверку буквы
 			result = (this->letters.count(letter) > 0);
 		}
@@ -1237,7 +1292,7 @@ const bool anyks::Alphabet::checkHome2(const wstring & word) const noexcept {
 	// Результат работы функции
 	bool result = false;
 	// Если слово передано, первая буква не является числом а последняя это число
-	if(!word.empty() && !this->isNumber({word.front()}) && this->isNumber({word.back()})){
+	if(!word.empty() && !this->isNumber(wstring(1, word.front())) && this->isNumber(wstring(1, word.back()))){
 		// Позиция дефиса в слове
 		size_t pos = 0;
 		// Ищим дефис в слове
@@ -1332,8 +1387,8 @@ const bool anyks::Alphabet::checkSimilars(const wstring & str) const noexcept {
 					// Выполняем проверку буквы
 					result = (
 						(letter != L'-') &&
-						!this->isNumber({letter}) &&
 						!this->isLatian({letter}) &&
+						!this->isNumber(wstring(1, letter)) &&
 						(this->letters.count(letter) > 0)
 					);
 				}
@@ -1625,7 +1680,9 @@ void anyks::Alphabet::add(const wchar_t letter) noexcept {
 	// Если буква передана и такой буквы еще нет
 	if((letter > 0) && (this->letters.count(letter) < 1)){
 		// Добавляем букву в список
-		if(!this->isNumber({letter}) && (this->allowedSymbols.count(letter) < 1)) this->letters.emplace(letter);
+		if(!this->isNumber(wstring(1, letter)) &&
+			(this->allowedSymbols.count(letter) < 1)
+		) this->letters.emplace(letter);
 	}
 }
 /**
